@@ -3,10 +3,10 @@ package URI::WithBase;
 use strict;
 use warnings;
 
-use URI;
-use Scalar::Util 'blessed';
+use URI ();
+use Scalar::Util qw(blessed);
 
-our $VERSION = '5.05';
+our $VERSION = '5.06';
 
 use overload '""' => "as_string", fallback => 1;
 
