@@ -6,10 +6,10 @@ package URI::_idna;
 use strict;
 use warnings;
 
-use URI::_punycode qw(encode_punycode decode_punycode);
+use URI::_punycode qw(decode_punycode encode_punycode);
 use Carp qw(croak);
 
-our $VERSION = '5.05';
+our $VERSION = '5.06';
 
 BEGIN {
   *URI::_idna::_ENV_::JOIN_LEAKS_UTF8_FLAGS = "$]" < 5.008_003
