@@ -12,9 +12,9 @@ use warnings;
 
 use parent qw(URI::_server URI::_userpass);
 
-use URI::Escape qw(uri_unescape);
+use URI::Escape ();
 
-our $VERSION = '5.05';
+our $VERSION = '5.06';
 
 sub default_port { 5060 }
 
